library(ecodist)

##Script for Semi-improved pasture


## Open vegetation and seed bank data matrix for the pasture plot and attach column names

plot1_veg <- read.table("plot1_veg_mantel.txt", header=T)
attach(plot1_veg) 

plot1_sb <- read.table("plot1_sb_mantel.txt", header=T)
attach(plot1_sb)

## Create dissimilarity matrices for vegetation, seed bank and x-y coordinates

xy_dist <- dist(plot1_veg[,1:2])
veg_pa <- distance(plot1_veg[,3:46], "bray-curtis")
##as.matrix(veg_pa)[1:10,]


## Need to open and close vegan package in order to use a distance measure not included in ecodist package
library(vegan)
sb_pa <- vegdist(plot1_sb[,3:46], method="horn")
detach(package:vegan)

## Command allows you to look at the first 10 lines of the matrix
##as.matrix(sb_pa)[1:10,]

## Perform simple mantel test crossing each matrix

veg_sb_pa <- mantel(veg_pa ~ sb_pa)
veg_xy_pa <- mantel(veg_pa ~ xy_dist)
sb_xy_pa <- mantel (sb_pa ~ xy_dist)

## Perform partial mantel of vegetation and seed bank controlling for x-y coordinates
partial_pa <- mantel(veg_pa ~ sb_pa + xy_dist)

## Mantel corrlogram of vegetation and seed bank
veg_gram_pa <- mgram(veg_pa, xy_dist)

sb_gram_pa <- mgram(sb_pa, xy_dist)

par(mfrow=c(1,2))
plot(veg_gram_pa, ylab="vegetation mantel r")
plot(sb_gram_pa, ylab="seed bank mantel r")



